<?php
require_once __DIR__ . '/../config/database.php';

class ElementoInspeccion {
    private $db;
    
    public function __construct() {
        $database = new Database();
        $this->db = $database->getConnection();
    }
    
    public function getBySeccion($seccion_id) {
        try {
            $query = "SELECT * FROM elementos_inspeccion WHERE seccion_id = ? ORDER BY orden ASC";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$seccion_id]);
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            error_log("Error en ElementoInspeccion::getBySeccion: " . $e->getMessage());
            return [];
        }
    }
    
    public function getById($id) {
        try {
            $query = "SELECT * FROM elementos_inspeccion WHERE id = ?";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$id]);
            return $stmt->fetch(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            error_log("Error en ElementoInspeccion::getById: " . $e->getMessage());
            return false;
        }
    }
    
    public function create($data) {
        try {
            $query = "INSERT INTO elementos_inspeccion (seccion_id, descripcion, orden, obligatorio, activo, tipo_respuesta) 
                     VALUES (?, ?, ?, ?, ?, ?)";
            $stmt = $this->db->prepare($query);
            $result = $stmt->execute([
                $data['seccion_id'],
                $data['descripcion'],
                $data['orden'] ?? 1,
                $data['obligatorio'] ?? 1,
                $data['activo'] ?? 1,
                $data['tipo_respuesta'] ?? 'si_no_nc'
            ]);
            
            if ($result) {
                return $this->db->lastInsertId();
            }
            return false;
        } catch (Exception $e) {
            error_log("Error en ElementoInspeccion::create: " . $e->getMessage());
            return false;
        }
    }
    
    public function update($id, $data) {
        try {
            $fields = [];
            $values = [];
            
            if (isset($data['descripcion'])) {
                $fields[] = "descripcion = ?";
                $values[] = $data['descripcion'];
            }
            
            if (isset($data['orden'])) {
                $fields[] = "orden = ?";
                $values[] = $data['orden'];
            }
            
            if (isset($data['obligatorio'])) {
                $fields[] = "obligatorio = ?";
                $values[] = $data['obligatorio'];
            }
            
            if (isset($data['activo'])) {
                $fields[] = "activo = ?";
                $values[] = $data['activo'];
            }
            
            if (isset($data['tipo_respuesta'])) {
                $fields[] = "tipo_respuesta = ?";
                $values[] = $data['tipo_respuesta'];
            }
            
            if (empty($fields)) {
                return false;
            }
            
            $values[] = $id;
            $query = "UPDATE elementos_inspeccion SET " . implode(', ', $fields) . " WHERE id = ?";
            $stmt = $this->db->prepare($query);
            return $stmt->execute($values);
        } catch (Exception $e) {
            error_log("Error en ElementoInspeccion::update: " . $e->getMessage());
            return false;
        }
    }
    
    public function delete($id) {
        try {
            // Verificar si tiene respuestas asociadas
            $query = "SELECT COUNT(*) FROM respuestas_inspeccion WHERE elemento_id = ?";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$id]);
            $count = $stmt->fetchColumn();
            
            if ($count > 0) {
                // No eliminar, solo desactivar
                return $this->update($id, ['activo' => 0]);
            }
            
            // Eliminar completamente si no tiene respuestas
            $query = "DELETE FROM elementos_inspeccion WHERE id = ?";
            $stmt = $this->db->prepare($query);
            return $stmt->execute([$id]);
        } catch (Exception $e) {
            error_log("Error en ElementoInspeccion::delete: " . $e->getMessage());
            return false;
        }
    }
    
    public function getMaxOrden($seccion_id) {
        try {
            $query = "SELECT MAX(orden) FROM elementos_inspeccion WHERE seccion_id = ?";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$seccion_id]);
            $max = $stmt->fetchColumn();
            return $max ? $max + 1 : 1;
        } catch (Exception $e) {
            error_log("Error en ElementoInspeccion::getMaxOrden: " . $e->getMessage());
            return 1;
        }
    }
    
    // Métodos para secciones
    public function createSeccion($data) {
        try {
            $query = "INSERT INTO secciones_inspeccion (tipo_inspeccion_id, nombre, descripcion, orden, activo) 
                     VALUES (?, ?, ?, ?, ?)";
            $stmt = $this->db->prepare($query);
            $result = $stmt->execute([
                $data['tipo_inspeccion_id'],
                $data['nombre'],
                $data['descripcion'] ?? null,
                $data['orden'] ?? $this->getMaxOrdenSeccion($data['tipo_inspeccion_id']),
                $data['activo'] ?? 1
            ]);
            
            if ($result) {
                return $this->db->lastInsertId();
            }
            return false;
        } catch (Exception $e) {
            error_log("Error en ElementoInspeccion::createSeccion: " . $e->getMessage());
            return false;
        }
    }
    
    public function updateSeccion($id, $data) {
        try {
            $fields = [];
            $values = [];
            
            if (isset($data['nombre'])) {
                $fields[] = "nombre = ?";
                $values[] = $data['nombre'];
            }
            
            if (isset($data['descripcion'])) {
                $fields[] = "descripcion = ?";
                $values[] = $data['descripcion'];
            }
            
            if (isset($data['orden'])) {
                $fields[] = "orden = ?";
                $values[] = $data['orden'];
            }
            
            if (isset($data['activo'])) {
                $fields[] = "activo = ?";
                $values[] = $data['activo'];
            }
            
            if (empty($fields)) {
                return false;
            }
            
            $values[] = $id;
            $query = "UPDATE secciones_inspeccion SET " . implode(', ', $fields) . " WHERE id = ?";
            $stmt = $this->db->prepare($query);
            return $stmt->execute($values);
        } catch (Exception $e) {
            error_log("Error en ElementoInspeccion::updateSeccion: " . $e->getMessage());
            return false;
        }
    }
    
    public function deleteSeccion($id) {
        try {
            $this->db->beginTransaction();
            
            // Eliminar elementos de la sección
            $query = "DELETE FROM elementos_inspeccion WHERE seccion_id = ?";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$id]);
            
            // Eliminar la sección
            $query = "DELETE FROM secciones_inspeccion WHERE id = ?";
            $stmt = $this->db->prepare($query);
            $result = $stmt->execute([$id]);
            
            $this->db->commit();
            return $result;
        } catch (Exception $e) {
            $this->db->rollBack();
            error_log("Error en ElementoInspeccion::deleteSeccion: " . $e->getMessage());
            return false;
        }
    }
    
    public function getSeccionById($id) {
        try {
            $query = "SELECT * FROM secciones_inspeccion WHERE id = ?";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$id]);
            return $stmt->fetch(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            error_log("Error en ElementoInspeccion::getSeccionById: " . $e->getMessage());
            return false;
        }
    }
    
    private function getMaxOrdenSeccion($tipo_id) {
        try {
            $query = "SELECT MAX(orden) FROM secciones_inspeccion WHERE tipo_inspeccion_id = ?";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$tipo_id]);
            $max = $stmt->fetchColumn();
            return $max ? $max + 1 : 1;
        } catch (Exception $e) {
            error_log("Error en ElementoInspeccion::getMaxOrdenSeccion: " . $e->getMessage());
            return 1;
        }
    }
}
?>
