<?php
require_once __DIR__ . '/../config/database.php';

class Equipo {
    private $db;
    
    public function __construct() {
        $database = new Database();
        $this->db = $database->getConnection();
    }
    
    public function getByInmuebleYTipo($inmueble_id, $tipo_inspeccion_id) {
        try {
            $query = "SELECT e.*, ti.nombre as tipo_nombre 
                     FROM equipos e 
                     LEFT JOIN tipos_inspeccion ti ON e.tipo_inspeccion_id = ti.id
                     WHERE e.inmueble_id = ? AND e.tipo_inspeccion_id = ? 
                     AND e.estado_equipo = 'activo'
                     ORDER BY e.codigo_equipo ASC";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$inmueble_id, $tipo_inspeccion_id]);
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            error_log("Error en Equipo::getByInmuebleYTipo: " . $e->getMessage());
            return [];
        }
    }
    
    public function getById($id) {
        try {
            $query = "SELECT e.*, ti.nombre as tipo_nombre, i.nombre as inmueble_nombre
                     FROM equipos e 
                     LEFT JOIN tipos_inspeccion ti ON e.tipo_inspeccion_id = ti.id
                     LEFT JOIN inmuebles i ON e.inmueble_id = i.id
                     WHERE e.id = ?";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$id]);
            return $stmt->fetch(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            error_log("Error en Equipo::getById: " . $e->getMessage());
            return false;
        }
    }
    
    public function create($data) {
        try {
            $query = "INSERT INTO equipos (inmueble_id, tipo_inspeccion_id, codigo_equipo, numero_serie, 
                     ubicacion, descripcion, fecha_instalacion, estado_equipo, observaciones) 
                     VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)";
            $stmt = $this->db->prepare($query);
            $result = $stmt->execute([
                $data['inmueble_id'],
                $data['tipo_inspeccion_id'],
                $data['codigo_equipo'],
                $data['numero_serie'] ?? null,
                $data['ubicacion'],
                $data['descripcion'] ?? null,
                $data['fecha_instalacion'] ?? null,
                $data['estado_equipo'] ?? 'activo',
                $data['observaciones'] ?? null
            ]);
            
            if ($result) {
                return $this->db->lastInsertId();
            }
            return false;
        } catch (Exception $e) {
            error_log("Error en Equipo::create: " . $e->getMessage());
            return false;
        }
    }
    
    public function update($id, $data) {
        try {
            $fields = [];
            $values = [];
            
            $allowed_fields = ['codigo_equipo', 'numero_serie', 'ubicacion', 'descripcion', 
                             'fecha_instalacion', 'fecha_ultimo_mantenimiento', 'estado_equipo', 'observaciones'];
            
            foreach ($allowed_fields as $field) {
                if (isset($data[$field])) {
                    $fields[] = "$field = ?";
                    $values[] = $data[$field];
                }
            }
            
            if (empty($fields)) {
                return false;
            }
            
            $values[] = $id;
            $query = "UPDATE equipos SET " . implode(', ', $fields) . " WHERE id = ?";
            $stmt = $this->db->prepare($query);
            return $stmt->execute($values);
        } catch (Exception $e) {
            error_log("Error en Equipo::update: " . $e->getMessage());
            return false;
        }
    }
    
    public function delete($id) {
        try {
            // En lugar de eliminar, marcamos como retirado
            return $this->update($id, ['estado_equipo' => 'retirado']);
        } catch (Exception $e) {
            error_log("Error en Equipo::delete: " . $e->getMessage());
            return false;
        }
    }
    
    public function getEstadisticas($inmueble_id = null, $tipo_inspeccion_id = null) {
        try {
            $where_conditions = ["e.estado_equipo != 'retirado'"];
            $params = [];
            
            if ($inmueble_id) {
                $where_conditions[] = "e.inmueble_id = ?";
                $params[] = $inmueble_id;
            }
            
            if ($tipo_inspeccion_id) {
                $where_conditions[] = "e.tipo_inspeccion_id = ?";
                $params[] = $tipo_inspeccion_id;
            }
            
            $where_clause = implode(' AND ', $where_conditions);
            
            $query = "SELECT 
                        COUNT(*) as total,
                        SUM(CASE WHEN e.estado_equipo = 'activo' THEN 1 ELSE 0 END) as activos,
                        SUM(CASE WHEN e.estado_equipo = 'inactivo' THEN 1 ELSE 0 END) as inactivos,
                        SUM(CASE WHEN e.estado_equipo = 'mantenimiento' THEN 1 ELSE 0 END) as mantenimiento,
                        ti.nombre as tipo_nombre
                     FROM equipos e
                     LEFT JOIN tipos_inspeccion ti ON e.tipo_inspeccion_id = ti.id
                     WHERE $where_clause
                     GROUP BY e.tipo_inspeccion_id, ti.nombre";
            
            $stmt = $this->db->prepare($query);
            $stmt->execute($params);
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            error_log("Error en Equipo::getEstadisticas: " . $e->getMessage());
            return [];
        }
    }
    
    public function generarCodigoAutomatico($inmueble_id, $tipo_inspeccion_id, $prefijo = null) {
        try {
            // Si no se proporciona prefijo, usar las primeras 3 letras del tipo
            if (!$prefijo) {
                $query = "SELECT nombre FROM tipos_inspeccion WHERE id = ?";
                $stmt = $this->db->prepare($query);
                $stmt->execute([$tipo_inspeccion_id]);
                $tipo = $stmt->fetch(PDO::FETCH_ASSOC);
                
                if ($tipo) {
                    $prefijo = strtoupper(substr($tipo['nombre'], 0, 3));
                } else {
                    $prefijo = 'EQP';
                }
            }
            
            // Obtener el último número usado
            $query = "SELECT codigo_equipo FROM equipos 
                     WHERE inmueble_id = ? AND tipo_inspeccion_id = ? 
                     AND codigo_equipo LIKE ? 
                     ORDER BY codigo_equipo DESC LIMIT 1";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$inmueble_id, $tipo_inspeccion_id, $prefijo . '-%']);
            $ultimo = $stmt->fetch(PDO::FETCH_ASSOC);
            
            $numero = 1;
            if ($ultimo) {
                // Extraer el número del último código
                $partes = explode('-', $ultimo['codigo_equipo']);
                if (count($partes) >= 2) {
                    $numero = intval(end($partes)) + 1;
                }
            }
            
            return $prefijo . '-' . str_pad($numero, 3, '0', STR_PAD_LEFT);
        } catch (Exception $e) {
            error_log("Error en Equipo::generarCodigoAutomatico: " . $e->getMessage());
            return 'EQP-001';
        }
    }
}
?>
