<?php
require_once 'config/database.php';

class SeguimientoProblemas {
    private $conn;
    private $table_name = "seguimiento_problemas";

    public function __construct() {
        $database = new Database();
        $this->conn = $database->getConnection();
    }

    public function crearProblemasDesdeInspeccion($inspeccion_id) {
    try {
        // Primero limpiar problemas existentes para esta inspección
        $this->limpiarProblemasInspeccion($inspeccion_id);
        
        // Obtener respuestas "NO" de la inspección
        $query = "SELECT ri.*, ei.descripcion as elemento_descripcion, ei.id as elemento_id,
                         s.nombre as seccion_nombre
                  FROM respuestas_inspeccion ri
                  JOIN elementos_inspeccion ei ON ri.elemento_id = ei.id
                  JOIN secciones_inspeccion s ON ei.seccion_id = s.id
                  WHERE ri.inspeccion_id = :inspeccion_id AND ri.respuesta = 'no'";
        
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':inspeccion_id', $inspeccion_id);
        $stmt->execute();
        
        $problemas = $stmt->fetchAll();
        
        if (empty($problemas)) {
            return true; // No hay problemas que registrar
        }
        
        // Insertar problemas en seguimiento
        $insert_query = "INSERT INTO " . $this->table_name . " 
                        (inspeccion_id, elemento_id, descripcion_problema, observaciones, fecha_creacion) 
                        VALUES (:inspeccion_id, :elemento_id, :descripcion_problema, :observaciones, NOW())";
        
        $insert_stmt = $this->conn->prepare($insert_query);
        
        foreach ($problemas as $problema) {
            $descripcion_completa = $problema['seccion_nombre'] . ': ' . $problema['elemento_descripcion'];
            
            $insert_stmt->bindParam(':inspeccion_id', $inspeccion_id);
            $insert_stmt->bindParam(':elemento_id', $problema['elemento_id']);
            $insert_stmt->bindParam(':descripcion_problema', $descripcion_completa);
            $insert_stmt->bindParam(':observaciones', $problema['observaciones']);
            $insert_stmt->execute();
        }
        
        return true;
    } catch (Exception $e) {
        error_log("Error en crearProblemasDesdeInspeccion: " . $e->getMessage());
        return false;
    }
}

    public function getProblemasPendientes() {
        $query = "SELECT sp.*, i.fecha_inspeccion, inm.nombre as inmueble_nombre, 
                         inm.direccion as inmueble_direccion, u.nombre as inspector_nombre,
                         ei.descripcion as elemento_descripcion, s.nombre as seccion_nombre
                  FROM " . $this->table_name . " sp
                  JOIN inspecciones i ON sp.inspeccion_id = i.id
                  JOIN inmuebles inm ON i.inmueble_id = inm.id
                  JOIN usuarios u ON i.inspector_id = u.id
                  JOIN elementos_inspeccion ei ON sp.elemento_id = ei.id
                  JOIN secciones_inspeccion s ON ei.seccion_id = s.id
                  WHERE sp.estado = 'pendiente'
                  ORDER BY sp.fecha_creacion DESC";
        
        $stmt = $this->conn->prepare($query);
        $stmt->execute();
        
        return $stmt->fetchAll();
    }

    public function getAllProblemas($filtro_estado = null) {
        $where_clause = "";
        if ($filtro_estado) {
            $where_clause = "WHERE sp.estado = :estado";
        }
        
        $query = "SELECT sp.*, i.fecha_inspeccion, inm.nombre as inmueble_nombre, 
                         inm.direccion as inmueble_direccion, u.nombre as inspector_nombre,
                         ei.descripcion as elemento_descripcion, s.nombre as seccion_nombre
                  FROM " . $this->table_name . " sp
                  JOIN inspecciones i ON sp.inspeccion_id = i.id
                  JOIN inmuebles inm ON i.inmueble_id = inm.id
                  JOIN usuarios u ON i.inspector_id = u.id
                  JOIN elementos_inspeccion ei ON sp.elemento_id = ei.id
                  JOIN secciones_inspeccion s ON ei.seccion_id = s.id
                  $where_clause
                  ORDER BY sp.fecha_creacion DESC";
        
        $stmt = $this->conn->prepare($query);
        if ($filtro_estado) {
            $stmt->bindParam(':estado', $filtro_estado);
        }
        $stmt->execute();
        
        return $stmt->fetchAll();
    }

    public function updateEstado($id, $estado, $notas = null, $usuario_id = null) {
        $query = "UPDATE " . $this->table_name . " 
                  SET estado = :estado, notas_seguimiento = :notas, usuario_seguimiento = :usuario_id
                  WHERE id = :id";
        
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':id', $id);
        $stmt->bindParam(':estado', $estado);
        $stmt->bindParam(':notas', $notas);
        $stmt->bindParam(':usuario_id', $usuario_id);
        
        return $stmt->execute();
    }

    public function getEstadisticas() {
        $query = "SELECT 
                    COUNT(*) as total,
                    SUM(CASE WHEN estado = 'pendiente' THEN 1 ELSE 0 END) as pendientes,
                    SUM(CASE WHEN estado = 'en_proceso' THEN 1 ELSE 0 END) as en_proceso,
                    SUM(CASE WHEN estado = 'resuelto' THEN 1 ELSE 0 END) as resueltos
                  FROM " . $this->table_name;
        
        $stmt = $this->conn->prepare($query);
        $stmt->execute();
        
        return $stmt->fetch();
    }

    public function getProblemasByInmueble() {
        $query = "SELECT inm.nombre as inmueble_nombre, 
                         COUNT(*) as total_problemas,
                         SUM(CASE WHEN sp.estado = 'pendiente' THEN 1 ELSE 0 END) as pendientes
                  FROM " . $this->table_name . " sp
                  JOIN inspecciones i ON sp.inspeccion_id = i.id
                  JOIN inmuebles inm ON i.inmueble_id = inm.id
                  GROUP BY inm.id, inm.nombre
                  ORDER BY total_problemas DESC";
        
        $stmt = $this->conn->prepare($query);
        $stmt->execute();
        
        return $stmt->fetchAll();
    }

    public function getProblemasByInspeccion($inspeccion_id) {
        $query = "SELECT * FROM " . $this->table_name . " WHERE inspeccion_id = :inspeccion_id";
        
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':inspeccion_id', $inspeccion_id);
        $stmt->execute();
        
        return $stmt->fetchAll();
    }

    public function limpiarProblemasInspeccion($inspeccion_id) {
        $query = "DELETE FROM " . $this->table_name . " WHERE inspeccion_id = :inspeccion_id";
        
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':inspeccion_id', $inspeccion_id);
        
        return $stmt->execute();
    }

    public function getProblemasAgrupadosPorInspeccion($filtro_estado = null, $filtro_inmueble = null) {
        $where_conditions = [];
        $params = [];
        
        if ($filtro_estado) {
            $where_conditions[] = "sp.estado = :estado";
            $params[':estado'] = $filtro_estado;
        }
        
        if ($filtro_inmueble) {
            $where_conditions[] = "inm.id = :inmueble_id";
            $params[':inmueble_id'] = $filtro_inmueble;
        }
        
        $where_clause = !empty($where_conditions) ? "WHERE " . implode(" AND ", $where_conditions) : "";
        
        // Primero obtener las inspecciones con problemas
        $query_inspecciones = "SELECT DISTINCT 
                                  i.id as inspeccion_id,
                                  i.fecha_inspeccion,
                                  inm.nombre as inmueble_nombre,
                                  inm.direccion as inmueble_direccion,
                                  u.nombre as inspector_nombre,
                                  COUNT(sp.id) as total_problemas,
                                  SUM(CASE WHEN sp.estado = 'pendiente' THEN 1 ELSE 0 END) as pendientes,
                                  SUM(CASE WHEN sp.estado = 'en_proceso' THEN 1 ELSE 0 END) as en_proceso,
                                  SUM(CASE WHEN sp.estado = 'resuelto' THEN 1 ELSE 0 END) as resueltos
                              FROM " . $this->table_name . " sp
                              JOIN inspecciones i ON sp.inspeccion_id = i.id
                              JOIN inmuebles inm ON i.inmueble_id = inm.id
                              JOIN usuarios u ON i.inspector_id = u.id
                              $where_clause
                              GROUP BY i.id, i.fecha_inspeccion, inm.nombre, inm.direccion, u.nombre
                              ORDER BY i.fecha_inspeccion DESC";
        
        $stmt = $this->conn->prepare($query_inspecciones);
        foreach ($params as $key => $value) {
            $stmt->bindValue($key, $value);
        }
        $stmt->execute();
        $inspecciones = $stmt->fetchAll();
        
        // Para cada inspección, obtener sus problemas
        $resultado = [];
        foreach ($inspecciones as $inspeccion) {
            $where_problemas = "WHERE sp.inspeccion_id = :inspeccion_id";
            $params_problemas = [':inspeccion_id' => $inspeccion['inspeccion_id']];
            
            if ($filtro_estado) {
                $where_problemas .= " AND sp.estado = :estado";
                $params_problemas[':estado'] = $filtro_estado;
            }
            
            $query_problemas = "SELECT sp.*, ei.descripcion as elemento_descripcion, s.nombre as seccion_nombre
                               FROM " . $this->table_name . " sp
                               JOIN elementos_inspeccion ei ON sp.elemento_id = ei.id
                               JOIN secciones_inspeccion s ON ei.seccion_id = s.id
                               $where_problemas
                               ORDER BY sp.fecha_creacion DESC";
            
            $stmt_problemas = $this->conn->prepare($query_problemas);
            foreach ($params_problemas as $key => $value) {
                $stmt_problemas->bindValue($key, $value);
            }
            $stmt_problemas->execute();
            $problemas = $stmt_problemas->fetchAll();
            
            $inspeccion['problemas'] = $problemas;
            $resultado[] = $inspeccion;
        }
        
        return $resultado;
    }
}
?>
