<?php
require_once __DIR__ . '/../config/database.php';

class TipoInspeccion {
    private $db;
    
    public function __construct() {
        $database = new Database();
        $this->db = $database->getConnection();
    }
    
    public function getAll() {
        try {
            $query = "SELECT * FROM tipos_inspeccion ORDER BY nombre ASC";
            $stmt = $this->db->prepare($query);
            $stmt->execute();
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            error_log("Error en TipoInspeccion::getAll: " . $e->getMessage());
            return [];
        }
    }
    
    public function getById($id) {
        try {
            $query = "SELECT * FROM tipos_inspeccion WHERE id = ?";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$id]);
            return $stmt->fetch(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            error_log("Error en TipoInspeccion::getById: " . $e->getMessage());
            return false;
        }
    }
    
    public function getActive() {
        try {
            $query = "SELECT * FROM tipos_inspeccion WHERE activo = 1 ORDER BY nombre ASC";
            $stmt = $this->db->prepare($query);
            $stmt->execute();
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            error_log("Error en TipoInspeccion::getActive: " . $e->getMessage());
            return [];
        }
    }
    
    public function create($data) {
        try {
            $query = "INSERT INTO tipos_inspeccion (nombre, descripcion, activo) VALUES (?, ?, ?)";
            $stmt = $this->db->prepare($query);
            $result = $stmt->execute([
                $data['nombre'],
                $data['descripcion'] ?? null,
                $data['activo'] ?? 1
            ]);
            
            if ($result) {
                return $this->db->lastInsertId();
            }
            return false;
        } catch (Exception $e) {
            error_log("Error en TipoInspeccion::create: " . $e->getMessage());
            return false;
        }
    }
    
    public function update($id, $data) {
        try {
            $fields = [];
            $values = [];
            
            if (isset($data['nombre'])) {
                $fields[] = "nombre = ?";
                $values[] = $data['nombre'];
            }
            
            if (isset($data['descripcion'])) {
                $fields[] = "descripcion = ?";
                $values[] = $data['descripcion'];
            }
            
            if (isset($data['activo'])) {
                $fields[] = "activo = ?";
                $values[] = $data['activo'];
            }
            
            if (empty($fields)) {
                return false;
            }
            
            $values[] = $id;
            $query = "UPDATE tipos_inspeccion SET " . implode(', ', $fields) . " WHERE id = ?";
            $stmt = $this->db->prepare($query);
            return $stmt->execute($values);
        } catch (Exception $e) {
            error_log("Error en TipoInspeccion::update: " . $e->getMessage());
            return false;
        }
    }
    
    public function delete($id) {
        try {
            // Verificar si tiene inspecciones asociadas
            $query = "SELECT COUNT(*) FROM inspecciones WHERE tipo_inspeccion_id = ?";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$id]);
            $count = $stmt->fetchColumn();
            
            if ($count > 0) {
                // No eliminar, solo desactivar
                return $this->update($id, ['activo' => 0]);
            }
            
            // Eliminar completamente si no tiene inspecciones
            $query = "DELETE FROM tipos_inspeccion WHERE id = ?";
            $stmt = $this->db->prepare($query);
            return $stmt->execute([$id]);
        } catch (Exception $e) {
            error_log("Error en TipoInspeccion::delete: " . $e->getMessage());
            return false;
        }
    }
    
    public function getSecciones($tipo_id) {
        try {
            $query = "SELECT * FROM secciones_inspeccion WHERE tipo_inspeccion_id = ? ORDER BY orden ASC";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$tipo_id]);
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            error_log("Error en TipoInspeccion::getSecciones: " . $e->getMessage());
            return [];
        }
    }
    
    public function getElementos($tipo_id) {
        try {
            $query = "SELECT e.*, s.nombre as seccion_nombre 
                     FROM elementos_inspeccion e 
                     JOIN secciones_inspeccion s ON e.seccion_id = s.id 
                     WHERE s.tipo_inspeccion_id = ? 
                     ORDER BY s.orden ASC, e.orden ASC";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$tipo_id]);
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            error_log("Error en TipoInspeccion::getElementos: " . $e->getMessage());
            return [];
        }
    }
    
    public function duplicar($id, $nuevo_nombre) {
        try {
            $this->db->beginTransaction();
            
            // Obtener tipo original
            $tipo_original = $this->getById($id);
            if (!$tipo_original) {
                throw new Exception("Tipo de inspección no encontrado");
            }
            
            // Crear nuevo tipo
            $nuevo_tipo_data = [
                'nombre' => $nuevo_nombre,
                'descripcion' => $tipo_original['descripcion'] . ' (Copia)',
                'activo' => 0 // Crear inactivo por defecto
            ];
            
            $nuevo_tipo_id = $this->create($nuevo_tipo_data);
            if (!$nuevo_tipo_id) {
                throw new Exception("Error al crear el nuevo tipo");
            }
            
            // Copiar secciones
            $secciones = $this->getSecciones($id);
            foreach ($secciones as $seccion) {
                $query = "INSERT INTO secciones_inspeccion (tipo_inspeccion_id, nombre, descripcion, orden, activo) 
                         VALUES (?, ?, ?, ?, ?)";
                $stmt = $this->db->prepare($query);
                $stmt->execute([
                    $nuevo_tipo_id,
                    $seccion['nombre'],
                    $seccion['descripcion'],
                    $seccion['orden'],
                    $seccion['activo']
                ]);
                
                $nueva_seccion_id = $this->db->lastInsertId();
                
                // Copiar elementos de la sección
                $query = "SELECT * FROM elementos_inspeccion WHERE seccion_id = ? ORDER BY orden ASC";
                $stmt = $this->db->prepare($query);
                $stmt->execute([$seccion['id']]);
                $elementos = $stmt->fetchAll(PDO::FETCH_ASSOC);
                
                foreach ($elementos as $elemento) {
                    $query = "INSERT INTO elementos_inspeccion (seccion_id, descripcion, orden, obligatorio, activo, tipo_respuesta) 
                             VALUES (?, ?, ?, ?, ?, ?)";
                    $stmt = $this->db->prepare($query);
                    $stmt->execute([
                        $nueva_seccion_id,
                        $elemento['descripcion'],
                        $elemento['orden'],
                        $elemento['obligatorio'],
                        $elemento['activo'],
                        $elemento['tipo_respuesta']
                    ]);
                }
            }
            
            $this->db->commit();
            return $nuevo_tipo_id;
            
        } catch (Exception $e) {
            $this->db->rollBack();
            error_log("Error en TipoInspeccion::duplicar: " . $e->getMessage());
            return false;
        }
    }
}
?>
