-- Script corregido para crear sistema de equipos
-- Verificar y crear tabla equipos sin claves foráneas primero

-- Crear tabla equipos sin claves foráneas
CREATE TABLE IF NOT EXISTS equipos (
    id INT AUTO_INCREMENT PRIMARY KEY,
    inmueble_id INT NOT NULL,
    tipo_inspeccion_id INT NOT NULL,
    codigo_equipo VARCHAR(50) NOT NULL,
    numero_serie VARCHAR(100) NULL,
    ubicacion VARCHAR(255) NOT NULL,
    descripcion TEXT NULL,
    fecha_instalacion DATE NULL,
    fecha_ultimo_mantenimiento DATE NULL,
    estado_equipo ENUM('activo', 'inactivo', 'mantenimiento', 'retirado') DEFAULT 'activo',
    observaciones TEXT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    INDEX idx_inmueble_tipo (inmueble_id, tipo_inspeccion_id),
    INDEX idx_estado (estado_equipo),
    INDEX idx_codigo (codigo_equipo),
    UNIQUE KEY unique_codigo_inmueble (codigo_equipo, inmueble_id)
);

-- Verificar si las tablas referenciadas existen antes de agregar claves foráneas
SET @inmuebles_exists = (SELECT COUNT(*) FROM information_schema.tables 
    WHERE table_schema = DATABASE() AND table_name = 'inmuebles');

SET @tipos_inspeccion_exists = (SELECT COUNT(*) FROM information_schema.tables 
    WHERE table_schema = DATABASE() AND table_name = 'tipos_inspeccion');

-- Solo agregar claves foráneas si las tablas existen
SET @sql_fk_inmuebles = IF(@inmuebles_exists > 0, 
    'ALTER TABLE equipos ADD CONSTRAINT fk_equipos_inmueble 
     FOREIGN KEY (inmueble_id) REFERENCES inmuebles(id) ON DELETE CASCADE',
    'SELECT "Tabla inmuebles no existe, saltando clave foránea" as mensaje');

SET @sql_fk_tipos = IF(@tipos_inspeccion_exists > 0,
    'ALTER TABLE equipos ADD CONSTRAINT fk_equipos_tipo_inspeccion 
     FOREIGN KEY (tipo_inspeccion_id) REFERENCES tipos_inspeccion(id) ON DELETE CASCADE',
    'SELECT "Tabla tipos_inspeccion no existe, saltando clave foránea" as mensaje');

-- Ejecutar las consultas preparadas
PREPARE stmt_inmuebles FROM @sql_fk_inmuebles;
EXECUTE stmt_inmuebles;
DEALLOCATE PREPARE stmt_inmuebles;

PREPARE stmt_tipos FROM @sql_fk_tipos;
EXECUTE stmt_tipos;
DEALLOCATE PREPARE stmt_tipos;

-- Verificar si la tabla respuestas_inspeccion existe antes de modificarla
SET @respuestas_exists = (SELECT COUNT(*) FROM information_schema.tables 
    WHERE table_schema = DATABASE() AND table_name = 'respuestas_inspeccion');

-- Solo modificar respuestas_inspeccion si existe
SET @sql_respuestas = IF(@respuestas_exists > 0,
    'ALTER TABLE respuestas_inspeccion 
     ADD COLUMN IF NOT EXISTS equipo_id INT NULL AFTER elemento_id,
     ADD INDEX IF NOT EXISTS idx_equipo (equipo_id)',
    'SELECT "Tabla respuestas_inspeccion no existe, saltando modificación" as mensaje');

PREPARE stmt_respuestas FROM @sql_respuestas;
EXECUTE stmt_respuestas;
DEALLOCATE PREPARE stmt_respuestas;

-- Agregar clave foránea a respuestas_inspeccion si ambas tablas existen
SET @sql_fk_respuestas = IF(@respuestas_exists > 0,
    'ALTER TABLE respuestas_inspeccion 
     ADD CONSTRAINT fk_respuestas_equipo 
     FOREIGN KEY (equipo_id) REFERENCES equipos(id) ON DELETE CASCADE',
    'SELECT "Saltando clave foránea respuestas_inspeccion" as mensaje');

PREPARE stmt_fk_respuestas FROM @sql_fk_respuestas;
EXECUTE stmt_fk_respuestas;
DEALLOCATE PREPARE stmt_fk_respuestas;

-- Insertar algunos equipos de ejemplo solo si las tablas referenciadas existen
INSERT IGNORE INTO equipos (inmueble_id, tipo_inspeccion_id, codigo_equipo, ubicacion, descripcion, estado_equipo) 
SELECT 
    1 as inmueble_id,
    1 as tipo_inspeccion_id,
    'BOMBA-001' as codigo_equipo,
    'Cuarto de Máquinas Principal' as ubicacion,
    'Bomba Principal 500 GPM' as descripcion,
    'activo' as estado_equipo
WHERE EXISTS (SELECT 1 FROM inmuebles WHERE id = 1)
  AND EXISTS (SELECT 1 FROM tipos_inspeccion WHERE id = 1);

INSERT IGNORE INTO equipos (inmueble_id, tipo_inspeccion_id, codigo_equipo, ubicacion, descripcion, estado_equipo) 
SELECT 
    1 as inmueble_id,
    2 as tipo_inspeccion_id,
    'EXT-001' as codigo_equipo,
    'Planta Baja - Recepción' as ubicacion,
    'Extintor ABC 6kg' as descripcion,
    'activo' as estado_equipo
WHERE EXISTS (SELECT 1 FROM inmuebles WHERE id = 1)
  AND EXISTS (SELECT 1 FROM tipos_inspeccion WHERE id = 2);

INSERT IGNORE INTO equipos (inmueble_id, tipo_inspeccion_id, codigo_equipo, ubicacion, descripcion, estado_equipo) 
SELECT 
    1 as inmueble_id,
    2 as tipo_inspeccion_id,
    'EXT-002' as codigo_equipo,
    'Primer Piso - Oficina A' as ubicacion,
    'Extintor ABC 6kg' as descripcion,
    'activo' as estado_equipo
WHERE EXISTS (SELECT 1 FROM inmuebles WHERE id = 1)
  AND EXISTS (SELECT 1 FROM tipos_inspeccion WHERE id = 2);

-- Mostrar resultado
SELECT 'Tabla equipos creada exitosamente' as resultado;
SELECT COUNT(*) as total_equipos_creados FROM equipos;
